TcpPacket class

Inheritance

Constructors

TcpPacket()

Properties

acknowledgementNumber int
4-byte TCP acknowledgement number at index 8
getter/setter pair
destinationAddress IpAddress
getter/setter pairinherited
destinationPort int
2-byte TCP destination port.
getter/setter pair
hashCode int
Determines hash by serializing this value.
no setteroverride
ipProtocolNumber int
no setteroverride
isAck bool
getter/setter pair
isFinished bool
getter/setter pair
isPush bool
getter/setter pair
isReset bool
getter/setter pair
isSelectiveAcknowledgementPermitted bool
getter/setter pair
isSynchronizeSequenceNumbers bool
getter/setter pair
isUrgentPointer bool
getter/setter pair
maximumSegmentSize int?
getter/setter pair
optionsByteData ByteData
getter/setter pair
optionsBytes Uint8List
getter/setter pair
parentPacket IpPacket<IpAddress>?
getter/setter pairinherited
payload SelfEncoder
getter/setter pair
protocol Protocol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectiveAcknowledgement List<int>?
getter/setter pair
sequenceNumber int
4-byte TCP sequence number at index 4
getter/setter pair
sourceAddress IpAddress
getter/setter pairinherited
sourcePort int
2-byte TCP source port.
getter/setter pair
urgentPointer int
getter/setter pair
window int
getter/setter pair
windowScale int?
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes state from the bytes.
override
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes state from the SelfEncoder.
inherited
encodeSelf(RawWriter writer) → void
Encodes this object.
override
encodeSelfCapacity() int
Returns an estimate of the maximum number of bytes needed to encode this value.
override
indexOfOption(int searchedCode) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOption(int code) → void
Removes all options that have the code.
setOptionWithLength(int code, int length) int
Adds the option to the TCP options. Returns index of the option.
toImmutableByteData() ByteData
Returns an immutable encoding of this value.
inherited
toImmutableBytes() List<int>
Returns an immutable encoding of this value.
inherited
toMutableByteData() ByteData
Returns a mutable encoding of this value.
inherited
toMutableBytes() List<int>
Returns a mutable encoding of this value.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Determines equality by serializing both values.
override