UdpPacket class

Inheritance

Constructors

UdpPacket()

Properties

destinationAddress IpAddress
getter/setter pairinherited
destinationPort int
UDP packet destination port.
getter/setter pair
hashCode int
Determines hash by serializing this value.
no setteroverride
ipProtocolNumber int
no setteroverride
parentPacket IpPacket<IpAddress>?
getter/setter pairinherited
payload SelfEncoder
UDP packet payload.
getter/setter pair
protocol Protocol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceAddress IpAddress
getter/setter pairinherited
sourcePort int
UDP packet source port.
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes state from the bytes.
override
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes state from the SelfEncoder.
inherited
encodeSelf(RawWriter writer) → void
Encodes this object.
override
encodeSelfCapacity() int
Returns an estimate of the maximum number of bytes needed to encode this value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() ByteData
Returns an immutable encoding of this value.
inherited
toImmutableBytes() List<int>
Returns an immutable encoding of this value.
inherited
toMutableByteData() ByteData
Returns a mutable encoding of this value.
inherited
toMutableBytes() List<int>
Returns a mutable encoding of this value.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Determines equality by serializing both values.
override