Ip4Packet class

Inheritance

Constructors

Ip4Packet()

Properties

destination Ip4Address
Destination IP address.
getter/setter pairinherited
flags int
3-bit flags.
getter/setter pair
fragmentOffset int
13-bit fragment offset.
getter/setter pair
hashCode int
Determines hash by serializing this value.
no setterinherited
identification int
16-bit identification
getter/setter pair
ipVersion int
IP version (4 or 6)
no setteroverride
options SelfEncoder
IPv4 options. Maximum length is 40 bytes.
getter/setter pair
payload SelfEncoder
getter/setter pairinherited-getteroverride-setter
payloadProtocolNumber int
8-bit encapsulated protocol (e.g. TCP, UDP).
getter/setter pairoverride-getter
protocol Protocol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Ip4Address
Source IP address.
getter/setter pairinherited
ttl int
8-bit time-to-live.
getter/setter pair
typeOfService int
8-bit type of service.
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes state from the bytes.
override
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes state from the SelfEncoder.
inherited
encodeSelf(RawWriter writer) → void
Encodes this object.
override
encodeSelfCapacity() int
Returns an estimate of the maximum number of bytes needed to encode this value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() ByteData
Returns an immutable encoding of this value.
inherited
toImmutableBytes() List<int>
Returns an immutable encoding of this value.
inherited
toMutableByteData() ByteData
Returns a mutable encoding of this value.
inherited
toMutableBytes() List<int>
Returns a mutable encoding of this value.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Determines equality by serializing both values.
inherited

Static Methods

calculateChecksum(ByteData byteData, int index, int length, {int checksum = 0}) int