Ip6Address class
- Inheritance
-
- Object
- SelfEncoder
- IpAddress
- Ip6Address
Constructors
- Ip6Address.decode(RawReader reader)
-
factory
-
Ip6Address.fromBytes(List<
int> bytes, int index) -
factory
Properties
- hashCode → int
-
Determines hash by serializing this value.
no setterinherited
- isIpv4 → bool
-
Inspects whether the address is IPv4 address or IPv6 mapping of IPv4
address.
no setteroverride
- isLocalNetwork → bool
-
Inspects whether the address is a local network address (e.g. 10.0.01).
no setteroverride
- isLoopback → bool
-
Inspects whether the address is loopback address (e.g. 127.0.0.1)
no setteroverride
- protocol → Protocol
-
Returns protocol (ipv4 or ipv6).
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- v0 → int
-
final
- v1 → int
-
final
- v2 → int
-
final
- v3 → int
-
final
Methods
-
encodeSelf(
RawWriter writer) → void -
Encodes this object.
override
-
encodeSelfCapacity(
) → int -
Returns an estimate of the maximum number of bytes needed to encode this
value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toImmutableByteData(
) → ByteData -
Returns an immutable encoding of this value.
inherited
-
toImmutableBytes(
) → List< int> -
Returns an immutable encoding of this value.
inherited
-
toMutableByteData(
) → ByteData -
Returns a mutable encoding of this value.
inherited
-
toMutableBytes(
) → List< int> -
Returns a mutable encoding of this value.
inherited
-
toString(
) → String -
Returns string representation of the address.
override
Operators
-
operator ==(
Object other) → bool -
Determines equality by serializing both values.
inherited
Static Properties
- any → Ip6Address
-
final
- broadcast → Ip6Address
-
final
- loopback → Ip6Address
-
final
- zero → Ip6Address
-
final
Static Methods
-
parse(
String source) → Ip6Address -
Parses either Ip4Address or Ip6Address.
override