Ip6Packet class

Inheritance

Constructors

Ip6Packet()

Properties

destination Ip6Address
Destination IP address.
getter/setter pairinherited
flowLabel int
20-bit flow label
getter/setter pair
hashCode int
Determines hash by serializing this value.
no setterinherited
hopLimit int
8-bit hop limit
getter/setter pair
ipVersion int
IP version (4 or 6)
no setteroverride
payload SelfEncoder
getter/setter pairinherited-getteroverride-setter
payloadProtocolNumber int
8-bit encapsulated protocol (e.g. TCP, UDP).
getter/setter pairoverride-getter
protocol Protocol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Ip6Address
Source IP address.
getter/setter pairinherited
trafficClass int
8-bit traffic class
getter/setter pair

Methods

decodeSelf(RawReader reader) → void
Decodes state from the bytes.
override
decodeSelfFromSelfEncoder(SelfEncoder value) → void
Decodes state from the SelfEncoder.
inherited
encodeSelf(RawWriter writer) → void
Encodes this object.
override
encodeSelfCapacity() int
Returns an estimate of the maximum number of bytes needed to encode this value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() ByteData
Returns an immutable encoding of this value.
inherited
toImmutableBytes() List<int>
Returns an immutable encoding of this value.
inherited
toMutableByteData() ByteData
Returns a mutable encoding of this value.
inherited
toMutableBytes() List<int>
Returns a mutable encoding of this value.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Determines equality by serializing both values.
inherited