IpAddress class abstract

Superclass of Ip4Address and Ip6Address.

Inheritance
Implementers

Constructors

IpAddress()
const

Properties

hashCode int
Determines hash by serializing this value.
no setterinherited
isIpv4 bool
Inspects whether the address is IPv4 address or IPv6 mapping of IPv4 address.
no setter
isLocalNetwork bool
Inspects whether the address is a local network address (e.g. 10.0.01).
no setter
isLoopback bool
Inspects whether the address is loopback address (e.g. 127.0.0.1)
no setter
protocol Protocol
Returns protocol (ipv4 or ipv6).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeSelf(RawWriter writer) → void
Encodes this object.
inherited
encodeSelfCapacity() int
Returns an estimate of the maximum number of bytes needed to encode this value.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toImmutableByteData() ByteData
Returns an immutable encoding of this value.
inherited
toImmutableBytes() List<int>
Returns an immutable encoding of this value.
inherited
toMutableByteData() ByteData
Returns a mutable encoding of this value.
inherited
toMutableBytes() List<int>
Returns a mutable encoding of this value.
inherited
toString() String
Returns string representation of the address.
override

Operators

operator ==(Object other) bool
Determines equality by serializing both values.
inherited

Static Methods

fromBytes(List<int> bytes) IpAddress
parse(String source) IpAddress
Parses either Ip4Address or Ip6Address.