IcmpPacket class
- Inheritance
-
- Object
- SelfEncoder
- Packet
- IcmpPacket
Constructors
Properties
- code ↔ int
-
getter/setter pair
- hashCode → int
-
Determines hash by serializing this value.
no setterinherited
- payload ↔ SelfEncoder
-
getter/setter pair
- protocol → Protocol
-
no setteroverride
- restOfHeader ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
getter/setter pair
Methods
-
decodeSelf(
RawReader reader) → void -
Decodes state from the bytes.
override
-
decodeSelfFromSelfEncoder(
SelfEncoder value) → void -
Decodes state from the SelfEncoder.
inherited
-
encodeSelf(
RawWriter writer) → void -
Encodes this object.
override
-
encodeSelfCapacity(
) → int -
Returns an estimate of the maximum number of bytes needed to encode this
value.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toImmutableByteData(
) → ByteData -
Returns an immutable encoding of this value.
inherited
-
toImmutableBytes(
) → List< int> -
Returns an immutable encoding of this value.
inherited
-
toMutableByteData(
) → ByteData -
Returns a mutable encoding of this value.
inherited
-
toMutableBytes(
) → List< int> -
Returns a mutable encoding of this value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
Determines equality by serializing both values.
inherited
Constants
- typeDestinationUnreachable → const int
- typeEchoReply → const int
- typeEchoRequest → const int
- typeEchoTimeExceeded → const int
- typeParameterProblem → const int
- typeRedirectMessage → const int
- typeRouterAdvertisement → const int
- typeRouterSolicitation → const int
- typeSourceQuench → const int