IpPacket<T extends IpAddress> class
abstract
- Inheritance
-
- Object
- SelfEncoder
- Packet
- IpPacket
- Implementers
Constructors
- IpPacket()
Properties
- destination ↔ T
-
Destination IP address.
getter/setter pair
- hashCode → int
-
Determines hash by serializing this value.
no setterinherited
- ipVersion → int
-
IP version (4 or 6)
no setter
- payload ↔ SelfEncoder
-
getter/setter pair
- payloadProtocolNumber → int
-
8-bit encapsulated protocol (e.g. TCP, UDP).
no setter
- protocol → Protocol
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ T
-
Source IP address.
getter/setter pair
Methods
-
decodeSelf(
RawReader reader) → void -
Decodes state from the bytes.
inherited
-
decodeSelfFromSelfEncoder(
SelfEncoder value) → void -
Decodes state from the SelfEncoder.
inherited
-
encodeSelf(
RawWriter writer) → void -
Encodes this object.
inherited
-
encodeSelfCapacity(
) → int -
Returns an estimate of the maximum number of bytes needed to encode this
value.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toImmutableByteData(
) → ByteData -
Returns an immutable encoding of this value.
inherited
-
toImmutableBytes(
) → List< int> -
Returns an immutable encoding of this value.
inherited
-
toMutableByteData(
) → ByteData -
Returns a mutable encoding of this value.
inherited
-
toMutableBytes(
) → List< int> -
Returns a mutable encoding of this value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
Determines equality by serializing both values.
inherited